@@ -48,7 +48,7 @@ class TimeEvent:
     def is_ready(self):
         """return  true if the event is ready to be fired"""
         now = self.timefunc()
-        if self.absolute < now:
+        if self.absolute <= now:
             return True
         return False
 
@@ -109,7 +109,8 @@ class RepositoryServer(object):
                 self.daemon.handleRequests(req_timeout)
             except select.error:
                 continue
-            self.trigger_events()
+            finally:
+                self.trigger_events()
 
     def quit(self):
         """stop the server"""
