@@ -108,8 +108,12 @@ class NavigationComponent(Component):
         view = self.cw_extra_kwargs.get('view')
         if view is not None and hasattr(view, 'page_navigation_url'):
             url = view.page_navigation_url(self, path, params)
-        else:
+        elif path in ('json', 'ajax'):
+            # 'ajax' is the new correct controller, but the old 'json'
+            # controller should still be supported
             url = self.ajax_page_url(**params)
+        else:
+            url = self._cw.build_url(path, **params)
         # XXX hack to avoid opening a new page containing the evaluation of the
         # js expression on ajax call
         if url.startswith('javascript:'):
@@ -118,9 +122,9 @@ class NavigationComponent(Component):
 
     def ajax_page_url(self, **params):
         divid = params.setdefault('divid', 'pageContent')
-        params['fname'] = 'view'
         params['rql'] = self.cw_rset.printable_rql()
-        return self._cw.build_url('ajax', **params)
+        return js_href("$(%s).loadxhtml(AJAX_PREFIX_URL, %s, 'get', 'swap')" % (
+            json_dumps('#'+divid), js.ajaxFuncArgs('view', params)))
 
     def page_link(self, path, params, start, stop, content):
         url = xml_escape(self.page_url(path, params, start, stop))
@@ -444,7 +448,7 @@ class EntityCtxComponent(CtxComponent):
         return domid(self.__regid__) + unicode(self.entity.eid)
 
     def lazy_view_holder(self, w, entity, oid, registry='views'):
-        """add a holder and return an url that may be used to replace this
+        """add a holder and return a URL that may be used to replace this
         holder by the html generate by the view specified by registry and
         identifier. Registry defaults to 'views'.
         """
