@@ -1,4 +1,4 @@
-# copyright 2003-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -17,8 +17,6 @@
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
 """WSGI request handler for cubicweb"""
 
-
-
 __docformat__ = "restructuredtext en"
 
 from itertools import chain, repeat, izip
@@ -92,29 +90,21 @@ class WSGIResponse(object):
         return iter(self.body)
 
 
-
 class CubicWebWSGIApplication(object):
     """This is the wsgi application which will be called by the
     wsgi server with the WSGI ``environ`` and ``start_response``
     parameters.
-
-    XXX: missing looping tasks and proper repository shutdown when
-    the application is stopped.
-    NOTE: no pyro
     """
 
-    def __init__(self, config, vreg=None):
-        self.appli = CubicWebPublisher(config, vreg=vreg)
+    def __init__(self, config):
+        self.appli = CubicWebPublisher(config)
         self.config = config
         self.base_url = self.config['base-url']
-        self.https_url = self.config['https-url']
         self.url_rewriter = self.appli.vreg['components'].select_or_none('urlrewriter')
 
     def _render(self, req):
         """this function performs the actual rendering
         """
-        if self.base_url is None:
-            self.base_url = self.config._base_url = req.base_url()
         try:
             path = req.path
             result = self.appli.handle_request(req, path)
